@@ -8,7 +8,7 @@ use strict;
 #se warnings;
 
 use JSON::XS ();
-use Socket;
+use Socket qw(SOL_SOCKET SO_RCVBUF);
 use Time::HiRes ();
 
 use AnyEvent;
@@ -31,7 +31,7 @@ use constant {
   DEFAULT_LOG_LEVEL      => 'info',
 };
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 our $logger;
 
 # }}}
@@ -567,6 +567,12 @@ sub start_server {
     },
   );
 
+  # Bump up SO_RCVBUF on UDP socket, to buffer up incoming
+  # UDP packets, to avoid massive packet loss when load
+  # is very high.
+  setsockopt($self->{server}->fh, SOL_SOCKET, SO_RCVBUF, 16*1024*1024)
+    or die "Couldn't set SO_RCVBUF: $!";
+
   # Management interface (TCP, for 'stats' command, etc...)
   $self->{mgmtServer} = AnyEvent::Socket::tcp_server $mgmt_host, $mgmt_port, sub {
     my ($fh, $host, $port) = @_
